@@ -1,3 +1,7 @@
+/**
+ * SPDX-FileCopyrightText: 2022 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
+ */
 // ***********************************************************
 // This example support/index.js is processed and
 // loaded automatically before your test files.
@@ -17,7 +21,7 @@
 import './commands.js'
 
 Cypress.on('uncaught:exception', (err) => {
-	return !err.message.includes('ResizeObserver loop limit exceeded')
+	return !err.message.includes('ResizeObserver loop limit exceeded') && !err.message.includes('ResizeObserver loop completed with undelivered notifications')
 })
 
 // Alternatively you can use CommonJS syntax:
