@@ -2,11 +2,18 @@ OC.L10N.register(
     "deck",
     {
     "Personal" : "Şəxsi",
+    "Finished" : "Bitdi",
     "Done" : "Done",
+    "The file was uploaded" : "Fayl yükləndi",
+    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Yüklənmiş fayl php.ini-də upload_max_filesize direktivini aşır",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Yüklənilən faylın həcmi HTML formasinda olan MAX_FILE_SIZE direktivində təyin dilmiş həcmi aşır.",
+    "The file was only partially uploaded" : "Fayl yalnız qismən yüklənib",
     "No file was uploaded" : "Heç bir fayl yüklənilmədi",
     "Missing a temporary folder" : "Müvəqqəti qovluq çatışmır",
+    "Could not write file to disk" : "Faylı diskə yazmaq mümkün olmadı",
+    "A PHP extension stopped the file upload" : "PHP uzantısı faylın yüklənməsini dayandırdı",
     "Cancel" : "Dayandır",
+    "Completed" : "Bitmişdir",
     "Details" : "Detallar",
     "Sharing" : "Paylaşılır",
     "Tags" : "Işarələr",
@@ -17,15 +24,16 @@ OC.L10N.register(
     "Delete" : "Sil",
     "Edit" : "Dəyişiklik et",
     "Download" : "Yüklə",
+    "Comments" : "Şərhlər",
     "Modified" : "Dəyişdirildi",
     "Save" : "Saxla",
     "Reply" : "Cavab",
     "Update" : "Yenilənmə",
     "Created:" : "Yaradıldı:",
     "Description" : "Açıqlanma",
-    "Completed" : "Bitmişdir",
     "(group)" : "(qrup)",
     "seconds ago" : "saniyələr öncə",
+    "Search" : "Axtarış",
     "Shared with you" : "Shared with you",
     "Today" : "Bu gün",
     "Tomorrow" : "Sabah",
