@@ -7,6 +7,7 @@ OC.L10N.register(
     "No file was uploaded" : "Nijedna datoteka nije učitana.",
     "Missing a temporary folder" : "Nedostaje privremeni direktorij.",
     "Cancel" : "Otkaži",
+    "Completed" : "Zavrženo",
     "Sharing" : "Dijeljenje",
     "Activity" : "Aktivnost",
     "Can edit" : "Can edit",
@@ -21,7 +22,8 @@ OC.L10N.register(
     "Save" : "Spremi",
     "Update" : "Ažuriraj",
     "Description" : "Opis",
-    "Completed" : "Zavrženo",
+    "Keyboard shortcuts" : "Tipkovni prečaci",
+    "Search" : "Search",
     "Shared with you" : "Shared with you",
     "Today" : "Danas",
     "Tomorrow" : "Sutra",
