@@ -21,6 +21,7 @@ OC.L10N.register(
     "Do you want to overwrite it?" : "¿Deseas sobre escribirlo?",
     "Add card" : "Agregar tarjeta",
     "Filter by tag" : "Filtrar por etiqueta",
+    "Completed" : "Completado",
     "Hide archived cards" : "Ocultar tarjetas archivadas",
     "Show archived cards" : "Mostrar tarjetas archivadas",
     "Details" : "Detalles",
@@ -45,9 +46,12 @@ OC.L10N.register(
     "Description" : "Descripción",
     "Formatting help" : "Ayuda de formato",
     "Remove due date" : "Eliminar fecha de expiración",
-    "Completed" : "Completado",
     "(group)" : "(grupo)",
     "seconds ago" : "hace segundos",
+    "Keyboard shortcuts" : "Atajos del teclado",
+    "Keyboard shortcut" : "Atajo del teclado",
+    "Action" : "Acción",
+    "Search" : "Buscar",
     "Archived boards" : "Tableros archivados",
     "Shared with you" : "Compartido con usted",
     "Board details" : "Detalles del tablero",
@@ -59,7 +63,6 @@ OC.L10N.register(
     "Today" : "Hoy",
     "Tomorrow" : "Mañana",
     "Close" : "Cerrar",
-    "Share" : "Compartir",
-    "Due date" : "Fecha de vencimiento"
+    "Share" : "Compartir"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
