@@ -18,6 +18,8 @@ OC.L10N.register(
     "Invalid date, date format must be YYYY-MM-DD" : "Vigane kuupäev, formaat peab olema YYYY-MM-DD",
     "Cancel" : "Loobu",
     "File already exists" : "Fail on juba olemas",
+    "Open" : "Ava",
+    "Completed" : "Lõpetatud",
     "Details" : "Üksikasjad",
     "Sharing" : "Jagamine",
     "Tags" : "Sildid",
@@ -37,20 +39,19 @@ OC.L10N.register(
     "Update" : "Uuenda",
     "Created:" : "Loodud:",
     "Description" : "Kirjeldus",
-    "Completed" : "Lõpetatud",
     "(group)" : "(grupp)",
     "Delete card" : "Kustuta kaart",
     "seconds ago" : "sekundit tagasi",
+    "Keyboard shortcuts" : "Klaviatuuri otseteed",
+    "Keyboard shortcut" : "Klaviatuuri otsetee",
+    "Search" : "Otsi",
     "Shared with you" : "Sinuga jagatud",
+    "Cancel edit" : "Loobu muutmisest",
     "No notifications" : "Märguandeid pole",
     "An error occurred" : "Tekkis tõrge",
     "Today" : "Täna",
     "Tomorrow" : "Homme",
     "Close" : "Sulge",
-    "Share" : "Jaga",
-    "Timeline" : "Ajajoon",
-    "Due date" : "Tähtaeg",
-    "Next week" : "Järgmine nädal",
-    "Next month" : "Järgmine kuu"
+    "Share" : "Jaga"
 },
 "nplurals=2; plural=(n != 1);");
