@@ -102,13 +102,18 @@ OC.L10N.register(
     "Path is already shared with this card" : "הנתיב כבר משותף עם הכרטיס הזה",
     "Invalid date, date format must be YYYY-MM-DD" : "תאריך שגוי, תבנית התאריך חייבת להיות YYYY-MM-DD",
     "Personal planning and team project organization" : "ארגון אישי וקבוצתי של מיזמים",
+    "Card details" : "פרטי הכרטיס",
     "Add board" : "הוספת לוח",
     "Select the board to link to a project" : "נא לבחור את הלוח לקישור למיזם",
     "Search by board title" : "חיפוש לפי כותרת לו",
     "Select board" : "בחירת לוח",
+    "Move card to another board" : "העברת כרטיס ללוח אחר",
     "Select a board" : "נא לבחור לוח",
-    "Select a card" : "נא לבחור כרטיס",
+    "No lists available" : "אין רשימות זמינות",
+    "Select a list" : "בחר רשימה",
+    "Move card" : "העברת כרטיס",
     "Cancel" : "ביטול",
+    "Select a card" : "נא לבחור כרטיס",
     "Select the card to link to a project" : "נא לבחור את הכרטיס לקישור למיזם",
     "Link to card" : "קישור לכרטיס",
     "File already exists" : "הקובץ כבר קיים",
@@ -126,6 +131,8 @@ OC.L10N.register(
     "Filter by tag" : "סינון לפי תגית",
     "Filter by assigned user" : "סינון לפי משתמש מוקצה",
     "Unassigned" : "לא הוקצה",
+    "Open" : "פתוח",
+    "Completed" : "הושלם",
     "Filter by due date" : "סינון לפי תאריך יעד",
     "Overdue" : "באיחור",
     "Next 24 hours" : "ב־24 השעות הבאות",
@@ -139,9 +146,8 @@ OC.L10N.register(
     "Open details" : "פתיחת פרטים",
     "Details" : "פרטים",
     "Loading board" : "הלוח נטען",
-    "No lists available" : "אין רשימות זמינות",
-    "Create a new list to add cards to this board" : "צור רשימה חדשה כדי להוסיף כרטיסים ללוח זה",
     "Board not found" : "הלוח לא נמצא",
+    "Create a new list to add cards to this board" : "צור רשימה חדשה כדי להוסיף כרטיסים ללוח זה",
     "Sharing" : "שיתוף",
     "Tags" : "תגיות",
     "Deleted items" : "פריטים שנמחקו",
@@ -149,12 +155,9 @@ OC.L10N.register(
     "Deleted lists" : "רשימות שנמחקו",
     "Undo" : "ביטול",
     "Deleted cards" : "כרטיסים שנמחקו",
-    "Share board with a user, group or circle …" : "שיתוף לוח עם משתמש, קבוצה או מעגל…",
-    "Searching for users, groups and circles …" : "מחפש משתמשים, קבוצות, ומעגלים ...",
     "No participants found" : "לא נמצאו משתתפים",
     "Board owner" : "בעלות על הלוח",
     "(Group)" : "(קבוצה)",
-    "(Circle)" : "(מעגל)",
     "Can edit" : "ניתן לערוך",
     "Can share" : "Can share",
     "Can manage" : "הרשאת ניהול",
@@ -173,7 +176,6 @@ OC.L10N.register(
     "title and color value must be provided" : "יש לספק כותרת וערך צבע",
     "Board name" : "שם הלוח",
     "Members" : "חברים",
-    "Assign to users/groups/circles" : "הקצאה למשתמשים/קבוצות/מעגלים",
     "Assign a user to this card…" : "הקצאת משתמש לכרטיס זה…",
     "Upload new files" : "העלאת קבצים חדשים",
     "Share from Files" : "שיתוף מקבצים",
@@ -210,27 +212,27 @@ OC.L10N.register(
     "Choose attachment" : "בחירת קובץ מצורף",
     "Set a due date" : "הגדרת תאריך יעד",
     "Remove due date" : "הסרת מועד התפוגה",
-    "Completed" : "הושלם",
     "Unarchive card" : "הוצאת הכרטיס מהארכיון",
     "Archive card" : "העברת כרטיס לארכיון",
     "Select Date" : "בחירת תאריך",
     "Assign a tag to this card…" : "הקצאת תגית לכרטיס זה…",
     "(group)" : "(קבוצה)",
-    "Card details" : "פרטי הכרטיס",
     "Assign to me" : "הקצאה אלי",
     "Unassign myself" : "לבטל את הקצאת עצמי",
-    "Move card" : "העברת כרטיס",
     "Delete card" : "מחיקת כרטיס לארכיון",
-    "Move card to another board" : "העברת כרטיס ללוח אחר",
-    "Select a list" : "בחר רשימה",
-    "List is empty" : "הרשימה ריקה",
     "Card deleted" : "הכרטיס נמחק",
     "seconds ago" : "לפני מספר שניות",
+    "Keyboard shortcuts" : "קיצורי מקלדת",
+    "Keyboard shortcut" : "קיצור מקלדת",
+    "Action" : "פעולה",
+    "Shift" : "הזזה",
+    "Search" : "חיפוש",
     "All boards" : "כל הלוחות",
     "Archived boards" : "לוחות שנשמרו בארכיון",
     "Shared with you" : "משותף אתך",
     "Use bigger card view" : "להשתמש בתצוגת כרטיסים גדולה יותר",
     "Show boards in calendar/tasks" : "הצג הלוחות בלוח השנה/המשימות",
+    "Cancel edit" : "בטל עריכה",
     "Board details" : "פרטי לוח",
     "Edit board" : "עריכת לוח",
     "Clone board" : "שכפל את הלוח",
@@ -266,14 +268,8 @@ OC.L10N.register(
     "Share with a Deck card" : "שיתוף עם כרטיס חפיסה",
     "Share {file} with a Deck card" : "שיתוף {file} עם כרטיס חפיסה",
     "Share" : "שיתוף",
-    "A <strong>card description</strong> inside the Deck app has been changed" : "<strong>תיאור של כרטיס</strong> בתוך יישומון החבילה נערך",
-    "Timeline" : "ציר זמן",
-    "Add a new list" : "הוסף רשימה חדשה",
-    "Assign to users" : "הקצאה למשתמשים",
-    "Due date" : "מועד יעד",
-    "Next week" : "השבוע הבא",
-    "Next month" : "החודש הבא",
-    "Limit deck usage of groups" : "הגבלת השימוש בחבילה לקבוצות",
-    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "הגבלת חבילה תחסום משתמשים שאינם חלק מקבוצות אלו מיצירת לוחות משלהם. משתמשים עדיין יוכלו לעבור על לוחות ששותפו אתם."
+    "Searching for users, groups and circles …" : "מחפש משתמשים, קבוצות, ומעגלים ...",
+    "(Circle)" : "(מעגל)",
+    "Assign to users/groups/circles" : "הקצאה למשתמשים/קבוצות/מעגלים"
 },
-"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
+"nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");
