@@ -105,13 +105,18 @@ OC.L10N.register(
     "Path is already shared with this card" : "Put je već podijeljen s ovom karticom",
     "Invalid date, date format must be YYYY-MM-DD" : "Nevažeći datum, oblik datuma mora biti GGGG-MM-DD",
     "Personal planning and team project organization" : "Osobno planiranje i organizacija timskih projekata",
+    "Card details" : "Pojedinosti o kartici",
     "Add board" : "Dodaj ploču",
     "Select the board to link to a project" : "Odaberite ploču za povezivanje s projektom",
     "Search by board title" : "Traži po naslovu ploče",
     "Select board" : "Odaberi ploču",
+    "Move card to another board" : "Premjesti karticu na drugu ploču",
     "Select a board" : "Odaberite ploču",
-    "Select a card" : "Odaberite karticu",
+    "No lists available" : "Nema dostupnih popisa",
+    "Select a list" : "Odaberi popis",
+    "Move card" : "Premjesti karticu",
     "Cancel" : "Odustani",
+    "Select a card" : "Odaberite karticu",
     "Select the card to link to a project" : "Odaberite karticu za povezivanje s projektom",
     "Link to card" : "Poveznica na karticu",
     "File already exists" : "Datoteka već postoji",
@@ -129,6 +134,8 @@ OC.L10N.register(
     "Filter by tag" : "Filtriraj prema oznaci",
     "Filter by assigned user" : "Filtriraj prema dodijeljenom korisniku",
     "Unassigned" : "Nedodijeljeno",
+    "Open" : "Otvori",
+    "Completed" : "Završeno",
     "Filter by due date" : "Filtriraj prema datumu dospijeća",
     "Overdue" : "Kasni",
     "Next 24 hours" : "Sljedeća 24 sata",
@@ -142,9 +149,8 @@ OC.L10N.register(
     "Open details" : "Otvori pojedinosti",
     "Details" : "Pojedinosti",
     "Loading board" : "Učitavanje ploče",
-    "No lists available" : "Nema dostupnih popisa",
-    "Create a new list to add cards to this board" : "Stvorite novi popis kako biste dodali kartice na ovu ploču",
     "Board not found" : "Ploča nije pronađena",
+    "Create a new list to add cards to this board" : "Stvorite novi popis kako biste dodali kartice na ovu ploču",
     "Sharing" : "Dijeljenje",
     "Tags" : "Oznake",
     "Deleted items" : "Izbrisane stavke",
@@ -152,12 +158,9 @@ OC.L10N.register(
     "Deleted lists" : "Izbrisani popisi",
     "Undo" : "Poništi",
     "Deleted cards" : "Izbrisane kartice",
-    "Share board with a user, group or circle …" : "Dijelite ploču s korisnikom, grupom ili krugom...",
-    "Searching for users, groups and circles …" : "Traženje korisnika, grupa i krugova...",
     "No participants found" : "Nije pronađen nijedan sudionik",
     "Board owner" : "Vlasnik ploče",
     "(Group)" : "(Grupa)",
-    "(Circle)" : "(Krug)",
     "Can edit" : "Uređivanje moguće",
     "Can share" : "Dijeljenje moguće",
     "Can manage" : "Upravljanje moguće",
@@ -176,7 +179,6 @@ OC.L10N.register(
     "title and color value must be provided" : "potrebno je odabrati naziv i vrijednost boje",
     "Board name" : "Naziv ploče",
     "Members" : "Članovi",
-    "Assign to users/groups/circles" : "Dodijeli korisnicima/grupama/krugovima",
     "Assign a user to this card…" : "Dodijeli korisnika ovoj kartici...",
     "Upload new files" : "Otpremi nove datoteke",
     "Share from Files" : "Dijeli iz datoteka",
@@ -215,29 +217,29 @@ OC.L10N.register(
     "Choose attachment" : "Odaberi privitak",
     "Set a due date" : "Postavi datum dospijeća",
     "Remove due date" : "Ukloni datum dospijeća",
-    "Completed" : "Završeno",
+    "Mark as done" : "Označi kao završeno",
     "Unarchive card" : "Dearhiviraj karticu",
     "Archive card" : "Arhiviraj karticu",
     "Select Date" : "Odaberi datum",
     "Assign a tag to this card…" : "Dodijeli oznaku ovoj kartici...",
     "(group)" : "(grupa)",
     "{count} comments, {unread} unread" : "{count} komentara, {unread} nepročitanih",
-    "Card details" : "Pojedinosti o kartici",
     "Assign to me" : "Dodijeli meni",
     "Unassign myself" : "Ukloni sebe",
-    "Mark as done" : "Označi kao završeno",
-    "Move card" : "Premjesti karticu",
     "Delete card" : "Izbriši karticu",
-    "Move card to another board" : "Premjesti karticu na drugu ploču",
-    "Select a list" : "Odaberi popis",
-    "List is empty" : "Popis je prazan",
     "Card deleted" : "Kartica je izbrisana",
     "seconds ago" : "prije nekoliko sekundi",
+    "Keyboard shortcuts" : "Tipkovni prečaci",
+    "Keyboard shortcut" : "Tipkovni prečac",
+    "Action" : "Radnja",
+    "Shift" : "Pomakni",
+    "Search" : "Traži",
     "All boards" : "Sve ploče",
     "Archived boards" : "Arhivirane ploče",
     "Shared with you" : "Podijeljeno s vama",
     "Use bigger card view" : "Prikaži veće kartice",
     "Show boards in calendar/tasks" : "Prikaži ploče u kalendaru/zadacima",
+    "Cancel edit" : "Otkaži uređivanje",
     "Board details" : "Pojedinosti o ploči",
     "Edit board" : "Uredi ploču",
     "Clone board" : "Kloniraj ploču",
@@ -282,14 +284,8 @@ OC.L10N.register(
     "Share with a Deck card" : "Dijeli s Deck karticom",
     "Share {file} with a Deck card" : "Dijeli {file} s Deck karticom",
     "Share" : "Dijeli",
-    "A <strong>card description</strong> inside the Deck app has been changed" : "Promijenjen je <strong>opis kartice</strong> u aplikaciji Deck",
-    "Timeline" : "Vremenska crta",
-    "Add a new list" : "Dodaj novi popis",
-    "Assign to users" : "Dodijeli korisnicima",
-    "Due date" : "Datum dospijeća",
-    "Next week" : "Sljedeći tjedan",
-    "Next month" : "Sljedeći mjesec",
-    "Limit deck usage of groups" : "Ograniči uporabu decka grupama",
-    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Ograničenjem Decka možete spriječiti korisnike koji ne sudjeluju u tim grupama da stvaraju vlastite ploče. Korisnici će i dalje moći raditi na pločama koje su dijeljene s njima."
+    "Searching for users, groups and circles …" : "Traženje korisnika, grupa i krugova...",
+    "(Circle)" : "(Krug)",
+    "Assign to users/groups/circles" : "Dodijeli korisnicima/grupama/krugovima"
 },
 "nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
