@@ -72,6 +72,7 @@ OC.L10N.register(
     "The card \"%s\" on \"%s\" has reached its due date." : "Kartu \"%s\" pada \"%s\" telah melampaui tenggat.",
     "%s has mentioned you in a comment on \"%s\"." : "%s telah menyebut Anda didalam suatu komentar pada \"%s\".",
     "The board \"%s\" has been shared with you by %s." : "Papan \"%s\" telah dibagikan kepada Anda oleh %s.",
+    "Deck board" : "Papan Longgok",
     "No data was provided to create an attachment." : "Tidak ada data untuk membuat lampiran.",
     "Finished" : "Selesai",
     "To review" : "Perlu ditinjau",
@@ -96,13 +97,17 @@ OC.L10N.register(
     "Card not found" : "Kartu tidak ditemukan",
     "Invalid date, date format must be YYYY-MM-DD" : "Tanggal salah, format tanggal harus TTTT-BB-HH",
     "Personal planning and team project organization" : "Perencanaan pribadi dan pengelolaan proyek tim",
+    "Card details" : "Detail kartu",
     "Add board" : "Tambah papan",
     "Select the board to link to a project" : "Pilih papan untuk ditautkan ke proyek",
     "Search by board title" : "Cari berdasarkan judul papan",
     "Select board" : "Pilih papan",
+    "Move card to another board" : "Pindahkan kartu ke papan lain",
     "Select a board" : "Pilih papan",
-    "Select a card" : "Pilih kartu",
+    "Select a list" : "Pilih daftar",
+    "Move card" : "Pindahkan kartu",
     "Cancel" : "Membatalkan",
+    "Select a card" : "Pilih kartu",
     "Select the card to link to a project" : "Pilih kartu untuk ditautkan ke proyek",
     "Link to card" : "Tautan ke kartu",
     "File already exists" : "Berkas sudah ada",
@@ -120,6 +125,8 @@ OC.L10N.register(
     "Filter by tag" : "Filter dengan tag",
     "Filter by assigned user" : "Filter dengan pengguna",
     "Unassigned" : "Belum ditugaskan",
+    "Open" : "Buka",
+    "Completed" : "Selesai",
     "Filter by due date" : "Filter dengan tenggat",
     "Overdue" : "Lewat tenggat",
     "Next 24 hours" : "Jangka 24 jam",
@@ -139,10 +146,8 @@ OC.L10N.register(
     "Deleted lists" : "Daftar terhapus",
     "Undo" : "Undo",
     "Deleted cards" : "Kartu terhapus",
-    "Share board with a user, group or circle …" : "Bagikan papan kepada pengguna, grup atau lingkaran",
     "Board owner" : "Pemilik papan",
     "(Group)" : "(Grup)",
-    "(Circle)" : "(Lingkaran)",
     "Can edit" : "Can edit",
     "Can share" : "Can share",
     "Can manage" : "Dapat mengelola",
@@ -155,7 +160,6 @@ OC.L10N.register(
     "Add a new tag" : "Tambah tag baru",
     "title and color value must be provided" : "judul dan nilai warna harus ditentukan",
     "Members" : "Anggota",
-    "Assign to users/groups/circles" : "Penugasan kepada pengguna/grup/lingkaran",
     "Assign a user to this card…" : "Menugaskan pengguna kepada kartu ini..",
     "Add this attachment" : "Tambah lampiran ini",
     "Download" : "Unduh",
@@ -184,22 +188,21 @@ OC.L10N.register(
     "Choose attachment" : "Pilih lampiran",
     "Set a due date" : "Tentukan tenggat",
     "Remove due date" : "Hapus tenggat",
-    "Completed" : "Selesai",
+    "Mark as done" : "Tandai sebagai selesai",
     "Unarchive card" : "Memulihkan kartu",
     "Archive card" : "Mengarsipkan kartu",
     "Assign a tag to this card…" : "Berikan tag pada kartu ini...",
     "(group)" : "(grup)",
-    "Card details" : "Detail kartu",
     "Assign to me" : "Tugaskan saya",
-    "Mark as done" : "Tandai sebagai selesai",
-    "Move card" : "Pindahkan kartu",
     "Delete card" : "Hapus kartu",
-    "Move card to another board" : "Pindahkan kartu ke papan lain",
-    "Select a list" : "Pilih daftar",
     "seconds ago" : "beberapa detik yang lalu",
+    "Keyboard shortcuts" : "Pintasan keyboard",
+    "Keyboard shortcut" : "Pintasan keyboard",
+    "Search" : "Cari",
     "All boards" : "Semua papan",
     "Archived boards" : "Papan terarsip",
     "Shared with you" : "Shared with you",
+    "Cancel edit" : "Batal sunting",
     "Board details" : "Detail papan",
     "Edit board" : "Edit papan",
     "Clone board" : "Pengklonaan papan",
@@ -221,14 +224,7 @@ OC.L10N.register(
     "Something went wrong" : "Ada yang salah",
     "Maximum file size of {size} exceeded" : "Melampaui batas ukuran maksimal {size}",
     "Share" : "Bagikan",
-    "A <strong>card description</strong> inside the Deck app has been changed" : "<strong>Deskripsi kartu</strong> didalam aplikasi Longgok telah diubah",
-    "Timeline" : "Linimasa",
-    "Add a new list" : "Tambah daftar baru",
-    "Assign to users" : "Penugasan kepada pengguna",
-    "Due date" : "Tenggat",
-    "Next week" : "Minggu setelah",
-    "Next month" : "Bulan setelah",
-    "Limit deck usage of groups" : "Batasi grup pengguna longgok ",
-    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Membatasi Longgok akan mencegah pengguna bukan bagian dari grup, untuk membuat papan mereka sendiri. Pengguna tetap menggunakan papan yang telah dibagikan kepadanya."
+    "(Circle)" : "(Kelompok)",
+    "Assign to users/groups/circles" : "Penugasan kepada pengguna/grup/lingkaran"
 },
 "nplurals=1; plural=0;");
