@@ -9,6 +9,8 @@ OC.L10N.register(
     "No file was uploaded" : "Ulac afaylu i d-yettwasulin",
     "Missing a temporary folder" : "Ixuṣ ukaram akudan",
     "Cancel" : "Sefsex",
+    "Open" : "Ldi",
+    "Completed" : "Yemmed",
     "Details" : "Talqayt",
     "Sharing" : "Beṭṭu",
     "Tags" : "Tibzimin",
@@ -24,7 +26,8 @@ OC.L10N.register(
     "Save" : "Sekles",
     "Cancel reply" : "Semmet tiririt.",
     "Reply" : "Err",
-    "Completed" : "Yemmed",
+    "Search" : "Nadi",
+    "Cancel edit" : "Sefsex aseẓreg",
     "No notifications" : "Ulac tisezmal",
     "Today" : "Ass-a",
     "Close" : "Mdel",
