@@ -98,13 +98,18 @@ OC.L10N.register(
     "Path is already shared with this card" : "Kelias jau yra bendrinamas su šia kortele",
     "Invalid date, date format must be YYYY-MM-DD" : "Netinkama data, datos formatas privalo būti MMMM-mm-dd",
     "Personal planning and team project organization" : "Asmeninis planavimas ir komandinių projektų organizavimas",
+    "Card details" : "Išsamiau apie kortelę",
     "Add board" : "Pridėti lentą",
     "Select the board to link to a project" : "Pasirinkite lentą, kurią susieti su projektu",
     "Search by board title" : "Ieškoti pagal lentos pavadinimą",
     "Select board" : "Pasirinkti lentą",
+    "Move card to another board" : "Perkelti kortelę į kitą lentą",
     "Select a board" : "Pasirinkite lentą",
-    "Select a card" : "Pasirinkti kortelę",
+    "No lists available" : "Nėra sąrašų",
+    "Select a list" : "Pasirinkite sąrašą",
+    "Move card" : "Perkelti kortelę",
     "Cancel" : "Atsisakyti",
+    "Select a card" : "Pasirinkti kortelę",
     "Select the card to link to a project" : "Pasirinkite kortelę, kurią susieti su projektu",
     "Link to card" : "Susieti su kortele",
     "File already exists" : "Failas jau yra",
@@ -118,9 +123,12 @@ OC.L10N.register(
     "Archived cards" : "Archyvuotos kortelės",
     "Add list" : "Pridėti sąrašą",
     "List name" : "Sąrašo pavadinimas",
+    "Active filters" : "Aktyvūs filtrai",
     "Apply filter" : "Taikyti filtrą",
     "Filter by tag" : "Filtruoti pagal žymę",
     "Filter by assigned user" : "Filtruoti pagal priskirtą naudotoją",
+    "Open" : "Atverti",
+    "Completed" : "Užbaigta",
     "Filter by due date" : "Filtruoti pagal galutinio termino datą",
     "Overdue" : "Praėjęs galutinis terminas",
     "Next 24 hours" : "Artimiausios 24 val.",
@@ -133,9 +141,8 @@ OC.L10N.register(
     "Toggle compact mode" : "Perjungti kompaktišką veikseną",
     "Details" : "Išsamiau",
     "Loading board" : "Įkeliama lenta",
-    "No lists available" : "Nėra sąrašų",
-    "Create a new list to add cards to this board" : "Norėdami pridėti korteles į šią lentą, sukurkite naują sąrašą",
     "Board not found" : "Lenta nerasta",
+    "Create a new list to add cards to this board" : "Norėdami pridėti korteles į šią lentą, sukurkite naują sąrašą",
     "Sharing" : "Bendrinimas",
     "Tags" : "Žymės",
     "Deleted items" : "Ištrinti elementai",
@@ -143,12 +150,9 @@ OC.L10N.register(
     "Deleted lists" : "Ištrinti sąrašai",
     "Undo" : "Atšaukti",
     "Deleted cards" : "Ištrintos kortelės",
-    "Share board with a user, group or circle …" : "Bendrinti lentą su naudotoju, grupe ar ratu…",
-    "Searching for users, groups and circles …" : "Ieškoma naudotojų, grupių ir ratų…",
     "No participants found" : "Nerasta jokių dalyvių",
     "Board owner" : "Lentos savininkas",
     "(Group)" : "(Grupė)",
-    "(Circle)" : "(Ratas)",
     "Can edit" : "Gali redaguoti",
     "Can share" : "Can share",
     "Can manage" : "Gali tvarkyti",
@@ -167,7 +171,6 @@ OC.L10N.register(
     "title and color value must be provided" : "privalo būti pateiktos pavadinimo ir spalvos reikšmės",
     "Board name" : "Lentos pavadinimas",
     "Members" : "Nariai",
-    "Assign to users/groups/circles" : "Priskirti naudotojams/grupėms/ratams",
     "Assign a user to this card…" : "Priskirti šiai kortelei naudotoją…",
     "Upload new files" : "Išsiųsti naujus failus",
     "Share from Files" : "Bendrinti iš failų",
@@ -205,7 +208,7 @@ OC.L10N.register(
     "Choose attachment" : "Pasirinkite priedą",
     "Set a due date" : "Nustatyti galutinį terminą",
     "Remove due date" : "Šalinti galutinio termino datą",
-    "Completed" : "Užbaigta",
+    "Mark as done" : "Žymėti kaip atliktą",
     "Unarchive card" : "Išarchyvuoti kortelę",
     "Archive card" : "Archyvuoti kortelę",
     "Select Date" : "Pasirinkti datą",
@@ -213,21 +216,22 @@ OC.L10N.register(
     "(group)" : "(grupė)",
     "Next week – {timeLocale}" : "Kitą savaitę – {timeLocale}",
     "{count} comments, {unread} unread" : "Komentarų: {count}, neskaityta: {unread}",
-    "Card details" : "Išsamiau apie kortelę",
     "Assign to me" : "Priskirti sau",
-    "Mark as done" : "Žymėti kaip atliktą",
-    "Move card" : "Perkelti kortelę",
     "Delete card" : "Ištrinti kortelę",
-    "Move card to another board" : "Perkelti kortelę į kitą lentą",
-    "Select a list" : "Pasirinkite sąrašą",
-    "List is empty" : "Sąrašas tuščias",
     "Card deleted" : "Kortelė ištrinta",
     "seconds ago" : "prieš keletą sekundžių",
+    "Keyboard shortcuts" : "Spartieji klavišai",
+    "Keyboard shortcut" : "Spartusis klavišas",
+    "Action" : "Veiksmas",
+    "Shift" : "Lyg2",
+    "Ctrl" : "Vald",
+    "Search" : "Ieškoti",
     "All boards" : "Visos lentos",
     "Archived boards" : "Archyvuotos lentos",
     "Shared with you" : "Bendrinama su jumis",
     "Use bigger card view" : "Naudoti didesnį kortelių rodinį",
     "Show boards in calendar/tasks" : "Rodyti darbus kalendoriuje/užduotyse",
+    "Cancel edit" : "Atsisakyti taisymo",
     "Board details" : "Išsamiau apie lentą",
     "Edit board" : "Taisyti lentą",
     "Clone board" : "Dubliuoti lentą",
@@ -249,7 +253,6 @@ OC.L10N.register(
     "Tomorrow" : "Rytoj",
     "No due" : "Be galutinio termino",
     "No results found" : "Nerasta jokių rezultatų",
-    "This weekend – {timeLocale}" : "Šį savaitgalį – {timeLocale}",
     "Create a new card" : "Sukurti naują kortelę",
     "Card title" : "Kortelės pavadinimas",
     "Create card" : "Sukurti kortelę",
@@ -258,6 +261,8 @@ OC.L10N.register(
     "Open card" : "Atverti kortelę",
     "Close" : "Užverti",
     "Due on {date}" : "Galutinis terminas {date}",
+    "This weekend – {timeLocale}" : "Šį savaitgalį – {timeLocale}",
+    "Tomorrow – {timeLocale}" : "Rytoj – {timeLocale}",
     "Later today – {timeLocale}" : "Šiandien vėliau – {timeLocale}",
     "Link to a board" : "Susieti su lenta",
     "Link to a card" : "Susieti su kortele",
@@ -266,12 +271,8 @@ OC.L10N.register(
     "Maximum file size of {size} exceeded" : "Viršytas maksimalus {size} failo dydis",
     "Error creating the share" : "Klaida kuriant viešinį",
     "Share" : "Bendrinti",
-    "A <strong>card description</strong> inside the Deck app has been changed" : "Darbų programėlėje pakeistas <strong>kortelės aprašas</strong> ",
-    "Timeline" : "Laiko juosta",
-    "Add a new list" : "Pridėti naują sąrašą",
-    "Assign to users" : "Priskirti naudotojams",
-    "Due date" : "Galutinio termino data",
-    "Next week" : "Kita savaitė",
-    "Next month" : "Kitas mėnuo"
+    "Searching for users, groups and circles …" : "Ieškoma naudotojų, grupių ir ratų…",
+    "(Circle)" : "(Ratas)",
+    "Assign to users/groups/circles" : "Priskirti naudotojams/grupėms/ratams"
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
