@@ -98,13 +98,18 @@ OC.L10N.register(
     "Path is already shared with this card" : "Патеката веќе е споделена со оваа картица",
     "Invalid date, date format must be YYYY-MM-DD" : "Невалиден датум, форматот мора да биде ГГГГ-ММ-ДД",
     "Personal planning and team project organization" : "Персонален планер и тимски проект организер",
+    "Card details" : "Детали за картица",
     "Add board" : "Додади табла",
     "Select the board to link to a project" : "Избери табла за поврзување со проект",
     "Search by board title" : "Барај по име на табла",
     "Select board" : "Избери табла",
+    "Move card to another board" : "Премести ја картицата на друга табла",
     "Select a board" : "Избери табла",
-    "Select a card" : "Избери картица",
+    "No lists available" : "Нема достапни листи",
+    "Select a list" : "Избери листа",
+    "Move card" : "Премести картица",
     "Cancel" : "Откажи",
+    "Select a card" : "Избери картица",
     "Select the card to link to a project" : "Избери картица за поврзување со проект",
     "Link to card" : "Линк до картица",
     "File already exists" : "Датотека веќе постои",
@@ -122,6 +127,8 @@ OC.L10N.register(
     "Filter by tag" : "Филтрирај по ознака",
     "Filter by assigned user" : "Филтрирај по назначени корисници",
     "Unassigned" : "Неназначени",
+    "Open" : "Отвори",
+    "Completed" : "Завршено",
     "Filter by due date" : "Филтрирај по краен рок",
     "Overdue" : "Заостанати",
     "Next 24 hours" : "Следни 24 часа",
@@ -135,9 +142,8 @@ OC.L10N.register(
     "Open details" : "Отвори детали",
     "Details" : "Детали",
     "Loading board" : "Вчирување на табла",
-    "No lists available" : "Нема достапни листи",
-    "Create a new list to add cards to this board" : "Додадете нова листа за да додадете картици на таблата",
     "Board not found" : "Таблата не е пронајдена",
+    "Create a new list to add cards to this board" : "Додадете нова листа за да додадете картици на таблата",
     "Sharing" : "Споделување",
     "Tags" : "Ознаки",
     "Deleted items" : "Избришани работи",
@@ -145,12 +151,9 @@ OC.L10N.register(
     "Deleted lists" : "Избришани листи",
     "Undo" : "Врати",
     "Deleted cards" : "Избришани картици",
-    "Share board with a user, group or circle …" : "Сподели табла со корисник, група или круг ...",
-    "Searching for users, groups and circles …" : "Пребарување на корисници, групи или кругови ...",
     "No participants found" : "Не се пронајдени учесници",
     "Board owner" : "Сопственик на таблата",
     "(Group)" : "(Група)",
-    "(Circle)" : "(Круг)",
     "Can edit" : "Може да се уредува",
     "Can share" : "Can share",
     "Can manage" : "Може да ја менаџира",
@@ -169,7 +172,6 @@ OC.L10N.register(
     "title and color value must be provided" : "наслов и боја мора да се приложи",
     "Board name" : "Име на табла",
     "Members" : "Членови",
-    "Assign to users/groups/circles" : "Додели на корисници/групи/кругови",
     "Assign a user to this card…" : "Додели корисник на оваа картица...",
     "Upload new files" : "Прикачи нови датотеки",
     "Share from Files" : "Сподели од датотеките",
@@ -206,28 +208,29 @@ OC.L10N.register(
     "Choose attachment" : "Избери прилог",
     "Set a due date" : "Постави краен рок",
     "Remove due date" : "Отстрани краен рок",
-    "Completed" : "Завршено",
+    "Mark as done" : "Означи како готово",
     "Unarchive card" : "Врати картица од архива",
     "Archive card" : "Архивирај картица",
     "Select Date" : "Избери датум",
     "Assign a tag to this card…" : "Додади ознака на оваа картица...",
     "(group)" : "(group)",
-    "Card details" : "Детали за картица",
     "Assign to me" : "Доделени мене",
     "Unassign myself" : "Откажи се",
-    "Mark as done" : "Означи како готово",
-    "Move card" : "Премести картица",
     "Delete card" : "Избриши картица",
-    "Move card to another board" : "Премести ја картицата на друга табла",
-    "Select a list" : "Избери листа",
-    "List is empty" : "Листата е празна",
     "Card deleted" : "Картицата е избришана",
     "seconds ago" : "пред неколку секунди",
+    "Keyboard shortcuts" : "Кратенки преку тастатура",
+    "Keyboard shortcut" : "Кратенка преку тастатура",
+    "Shift" : "Shift",
+    "Ctrl" : "Ctrl",
+    "Search" : "Барај",
+    "Space" : "Празно место",
     "All boards" : "Сите табли",
     "Archived boards" : "Архивирани табли",
     "Shared with you" : "Споделено со тебе",
     "Use bigger card view" : "Користи поголем преглед на картици",
     "Show boards in calendar/tasks" : "Прикажи ги таблите во календарнот",
+    "Cancel edit" : "Откажи ажурирање",
     "Board details" : "Детали за таблата",
     "Edit board" : "Измени табла",
     "Clone board" : "Клонирај табла",
@@ -271,14 +274,8 @@ OC.L10N.register(
     "Share with a Deck card" : "Споделено со Deck картица",
     "Share {file} with a Deck card" : "Сподели {file} со Deck картица",
     "Share" : "Сподели",
-    "A <strong>card description</strong> inside the Deck app has been changed" : "<strong>Описот на картицата</strong> во апликацијата Deck е изменет",
-    "Timeline" : "Времеплов",
-    "Add a new list" : "Додади нова листа",
-    "Assign to users" : "Додели на корисници",
-    "Due date" : "До датум",
-    "Next week" : "Следна недела",
-    "Next month" : "Следен месец",
-    "Limit deck usage of groups" : "Ограничи ја апликацијата на групи",
-    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Ограничувањето на апликацијата ќе ги блокира корисниците кој не се дел од овие групи. Корсниците ќе можат да работат на апликацијата само доколку биде споделена табла со нив."
+    "Searching for users, groups and circles …" : "Пребарување на корисници, групи или кругови ...",
+    "(Circle)" : "(Круг)",
+    "Assign to users/groups/circles" : "Додели на корисници/групи/кругови"
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
