@@ -10,6 +10,8 @@ OC.L10N.register(
     "copy" : "Хуулах ",
     "Done" : "Хийсэн",
     "Cancel" : "болиулах",
+    "Open" : "Нээх",
+    "Completed" : "Гүйцэтгэгдсэн",
     "Hide archived cards" : "Архивлагдсан картуудыг нуух",
     "Show archived cards" : "Архивлагдсан картуудыг харах",
     "Details" : "Дэлгэрэнгүй",
@@ -33,16 +35,15 @@ OC.L10N.register(
     "Update" : "Шинэчлэх",
     "Created:" : "Үүсгэсэн:",
     "Description" : "Тайлбар",
-    "Completed" : "Гүйцэтгэгдсэн",
     "(group)" : "(бүлэг)",
     "seconds ago" : "хоёрдахь өмнө",
+    "Keyboard shortcut" : "Keyboard товчлуур",
+    "Search" : "Хайх",
     "Shared with you" : "тантай хуваалцсан",
     "No notifications" : "Мэдэгдэл байхгүй",
     "Today" : "өнөөдөр",
     "Tomorrow" : "маргааш",
     "Close" : "Хаах",
-    "Share" : "Түгээх",
-    "Next week" : "Дараа 7 хоног",
-    "Next month" : "Дараа сар"
+    "Share" : "Түгээх"
 },
 "nplurals=2; plural=(n != 1);");
