@@ -16,6 +16,8 @@ OC.L10N.register(
     "Cancel" : "Anullar",
     "File already exists" : "Lo fichièr existís ja",
     "Drop your files to upload" : "Depausatz los fichièrs d’enviar",
+    "Open" : "Dobrir",
+    "Completed" : "Acabat",
     "Details" : "Detalhs",
     "Sharing" : "Partiment",
     "Tags" : "Etiquetas",
@@ -43,9 +45,12 @@ OC.L10N.register(
     "Update" : "Metre a jorn",
     "Created:" : "Creat lo :",
     "Description" : "Descripcion",
-    "Completed" : "Acabat",
     "seconds ago" : "fa qualques segondas",
+    "Keyboard shortcuts" : "Acorchis de clavièr",
+    "Keyboard shortcut" : "Acorchis de clavièr",
+    "Search" : "Recercar",
     "Shared with you" : "Shared with you",
+    "Cancel edit" : "Anullar la modificacion",
     "No notifications" : "Cap de notificacion",
     "An error occurred" : "Una error s’es producha",
     "Today" : "Uèi",
@@ -54,9 +59,8 @@ OC.L10N.register(
     "Create a new card" : "Crear una carta novèla",
     "Create card" : "Crear una carta",
     "Close" : "Tampar",
+    "Tomorrow – {timeLocale}" : "Deman – {timeLocale}",
     "Create a card" : "Crear una carta",
-    "Share" : "Partejar",
-    "Next week" : "Setmana seguenta",
-    "Next month" : "Mes seguent"
+    "Share" : "Partejar"
 },
 "nplurals=2; plural=(n > 1);");
