@@ -21,6 +21,7 @@ OC.L10N.register(
     "File already exists" : "Skedari ekziston tashmë",
     "Do you want to overwrite it?" : "Doni ta rishkruani atë?",
     "Add card" : "Shto kartë",
+    "Completed" : "Të plotësuara",
     "Hide archived cards" : "Fsheh kartat e arkivuara ",
     "Show archived cards" : "Trego kartat e arkivuara",
     "Open details" : "Hapni detajet",
@@ -47,11 +48,13 @@ OC.L10N.register(
     "Description" : "Përshkrim",
     "Formatting help" : "Ndihmë formatimi",
     "Remove due date" : "Hiq datën e mbarimit",
-    "Completed" : "Të plotësuara",
     "Select Date" : "Zgjidhni Datën",
     "(group)" : "(grup)",
-    "List is empty" : "Lista është bosh",
     "seconds ago" : "sekonda më parë",
+    "Keyboard shortcuts" : "Shkurtoret e tastierës",
+    "Keyboard shortcut" : "Shkurtore tastiere",
+    "Action" : "Veprim",
+    "Search" : "Kërko",
     "Archived boards" : "Borde të arkivuara",
     "Shared with you" : "E ndarë me ju",
     "Board details" : "Detajet e Tabeles ",
@@ -63,7 +66,6 @@ OC.L10N.register(
     "Today" : "Sot",
     "Tomorrow" : "Nesër",
     "Close" : "Mbylleni",
-    "Share" : "Shpërndaje",
-    "Due date" : "Data e vendosur"
+    "Share" : "Shpërndaje"
 },
 "nplurals=2; plural=(n != 1);");
