@@ -18,6 +18,8 @@ OC.L10N.register(
     "Cancel" : "ยกเลิก",
     "File already exists" : "ไฟล์นี้มีอยู่แล้ว",
     "Add list" : "เพิ่มรายการ",
+    "Open" : "เปิด",
+    "Completed" : "เสร็จแล้ว",
     "Overdue" : "เกินกำหนด",
     "Details" : "รายละเอียด",
     "Sharing" : "การแชร์",
@@ -41,9 +43,11 @@ OC.L10N.register(
     "Update" : "อัปเดต",
     "Created:" : "สร้างเมื่อ:",
     "Description" : "รายละเอียด",
-    "Completed" : "เสร็จแล้ว",
     "(group)" : "(กลุ่ม)",
     "seconds ago" : "วินาทีที่ผ่านมา",
+    "Keyboard shortcuts" : "แป้นพิมพ์ลัด",
+    "Keyboard shortcut" : "แป้นพิมพ์ลัด",
+    "Search" : "ค้นหา",
     "Shared with you" : "แชร์กับคุณ",
     "Edit board" : "แก้ไขกระดาน",
     "No notifications" : "ไม่มีการแจ้งเตือน",
@@ -52,7 +56,6 @@ OC.L10N.register(
     "Today" : "วันนี้",
     "Tomorrow" : "พรุ่งนี้",
     "Close" : "ปิด",
-    "Share" : "แชร์",
-    "Due date" : "วันที่ครบกำหนด"
+    "Share" : "แชร์"
 },
 "nplurals=1; plural=0;");
