@@ -8,7 +8,7 @@ OC.L10N.register(
     "You have restored the board {board}" : "Ви відновили дошку {board}",
     "{user} has restored the board {board}" : "{user} відновив дошку {board}",
     "You have shared the board {board} with {acl}" : "Ви поділилися дошкою {board} з {acl}",
-    "{user} has shared the board {board} with {acl}" : "{user} поділився дошкою {board} з {acl}",
+    "{user} has shared the board {board} with {acl}" : "{user} поділив(-ла-)ся дошкою {board} з {acl}",
     "You have removed {acl} from the board {board}" : "Ви вилучили {acl} з дошки {board}",
     "{user} has removed {acl} from the board {board}" : "{user} вилучив {acl} з дошки {board}",
     "You have renamed the board {before} to {board}" : "Ви перейменували дошку з {before} на {board}",
@@ -32,6 +32,22 @@ OC.L10N.register(
     "You have added a description to card {card} in list {stack} on board {board}" : "Ви додали опис картки {card} у списку {stack} на дошці {board}",
     "{user} has added a description to card {card} in list {stack} on board {board}" : "{user} додав(-ла) опис до картки {card} у списку {stack} на дошці {board}",
     "You have updated the description of card {card} in list {stack} on board {board}" : "Ви оновили опис картки {card} у списку {stack} на дошці {board}",
+    "{user} has updated the description of the card {card} in list {stack} on board {board}" : "{user} оновив(-ла) опис до картки {card} у списку {stack} на дошці {board}",
+    "You have archived card {card} in list {stack} on board {board}" : "Ви архівували картку {card} у списку {stack} на дошці {board}",
+    "{user} has archived card {card} in list {stack} on board {board}" : "{user} архівув(-ла) картку {card} у списку {stack} на дошці {board}",
+    "You have unarchived card {card} in list {stack} on board {board}" : "Ви розархівували картку {card} у списку {stack} на дошці {board}",
+    "{user} has unarchived card {card} in list {stack} on board {board}" : "{user} розархівував(-ла) картку {card} у списку {stack} на дошці {board}",
+    "You have marked the card {card} as done in list {stack} on board {board}" : "Ви позначили як виконану картку {card} у списку {stack} на дошці {board}",
+    "{user} has marked card {card} as done in list {stack} on board {board}" : "{user} позначив(-ла) як виконану картку {card} у списку {stack} на дошці {board}",
+    "You have marked the card {card} as undone in list {stack} on board {board}" : "Ви позначили як не виконану картку {card} у списку {stack} на дошці {board}",
+    "{user} has marked the card {card} as undone in list {stack} on board {board}" : "{user} позначив(-ла) як не виконану картку {card} у списку {stack} на дошці {board}",
+    "You have removed the due date of card {card}" : "Ви вилучили дату завершення картки {card}",
+    "{user} has removed the due date of card {card}" : "{user} вилучив(-ла) дату завершення картки {card}",
+    "You have set the due date of card {card} to {after}" : "Ви встановили дату завершення картки {card} на {after}",
+    "{user} has set the due date of card {card} to {after}" : "{user} встановив(-ла) дату завершення картки {card} на {after}",
+    "You have updated the due date of card {card} to {after}" : "Ви оновили дату завершення картки {card} на {after}",
+    "{user} has updated the due date of card {card} to {after}" : "{user} оновив(-ла) дату завершення картки {card} на {after}",
+    "You have added the tag {label} to card {card} in list {stack} on board {board}" : "Ви додали мітку {label} до картки {card} в списку {board}",
     "Deck" : "Колода",
     "Changes in the <strong>Deck app</strong>" : "Зміни у застосунку <strong>Колода</strong>",
     "Upcoming cards" : "Очікують на виконання",
@@ -52,22 +68,26 @@ OC.L10N.register(
     "Example Task 1" : "Приклад завдання 1",
     "The file was uploaded" : "Файл завантажено",
     "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Файл для завантаження перевищує параметр upload_max_filesize у php.ini",
-    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Розмір вивантаженого файлу перевищує директиву MAX_FILE_SIZE вказану в HTML формі",
+    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Розмір завантаженого файлу перевищує значення MAX_FILE_SIZE, яке було зазначено у HTML формі",
     "The file was only partially uploaded" : "Файл завантажено частково",
-    "No file was uploaded" : "Не вивантажено жодного файлу",
+    "No file was uploaded" : "Жодного файлу не було завантажено",
     "Missing a temporary folder" : "Відсутній каталог тимчасових файлів",
     "Could not write file to disk" : "Неможливо записати файл на диск",
     "A PHP extension stopped the file upload" : "Розширення PHP призупинило завантаження файлу",
     "No file uploaded or file size exceeds maximum of %s" : "Немає завантажених файлів або розмір файлу перевищує максимум %s",
     "Card not found" : "Картку не знайдено",
     "Invalid date, date format must be YYYY-MM-DD" : "Недійсна дата, формат дати має бути РРРР-ММ-ДД",
+    "Card details" : "Деталі картки",
     "Add board" : "Додати дошку",
     "Select the board to link to a project" : "Виберіть дошку для прив'зки до проєкту",
     "Search by board title" : "Шукати за назвою дошки",
     "Select board" : "Вибрати дошку",
+    "Move card to another board" : "Перемістити картку до іншої дошки",
     "Select a board" : "Вибрати дошку",
-    "Select a card" : "Вибрати картку",
+    "Select a list" : "Виберіть список",
+    "Move card" : "Пересунути картку",
     "Cancel" : "Скасувати",
+    "Select a card" : "Вибрати картку",
     "Select the card to link to a project" : "Виберіть картку для прив'язки до проєкту",
     "Link to card" : "Прив'язати до картки",
     "File already exists" : "Файл вже існує",
@@ -81,10 +101,13 @@ OC.L10N.register(
     "Archived cards" : "Архівні картки",
     "Add list" : "Додати список",
     "List name" : "Назва списку",
+    "Active filters" : "Активні фільтри",
     "Apply filter" : "Відфільтрувати",
     "Filter by tag" : "Відібрати за мітками",
     "Filter by assigned user" : "Відібрати за призначеним користувачем",
     "Unassigned" : "Скасовано призначення",
+    "Open" : "Відкрити",
+    "Completed" : "Виконано",
     "Filter by due date" : "Відібрати за датою завершення",
     "Overdue" : "Протерміновано",
     "Next 7 days" : "Наступні 7 днів",
@@ -97,8 +120,8 @@ OC.L10N.register(
     "Open details" : "Показати деталі",
     "Details" : "Деталі",
     "Loading board" : "Завантаження дошки",
-    "Create a new list to add cards to this board" : "Створіть список щоб додати картки на цю дошку",
     "Board not found" : "Дошку не знайдено",
+    "Create a new list to add cards to this board" : "Створіть список щоб додати картки на цю дошку",
     "Sharing" : "Поділитися",
     "Tags" : "Мітки",
     "Deleted items" : "Вилучені елементи",
@@ -106,10 +129,8 @@ OC.L10N.register(
     "Deleted lists" : "Вилучені списки",
     "Undo" : "Скасувати",
     "Deleted cards" : "Вилучені картки",
-    "Share board with a user, group or circle …" : "Поділитися дошкою з користувачем, групою або колом...",
     "Board owner" : "Власник дошки",
     "(Group)" : "(група)",
-    "(Circle)" : "(Коло)",
     "Can edit" : "Можна редагувати",
     "Can share" : "Can share",
     "Can manage" : "Може керувати",
@@ -123,7 +144,6 @@ OC.L10N.register(
     "title and color value must be provided" : "потрібно зазначити назву та колір",
     "Board name" : "Назва дошки",
     "Members" : "Учасники",
-    "Assign to users/groups/circles" : "Призначити користувачам/групам/колам",
     "Assign a user to this card…" : "Призначити користувачеві цю картку",
     "Upload new files" : "Додати файл",
     "Share from Files" : "Відкрити Файли",
@@ -157,29 +177,32 @@ OC.L10N.register(
     "Set a due date" : "Встановити дату завершення",
     "Choose a date" : "Виберіть дату",
     "Remove due date" : "Вилучити до",
-    "Completed" : "Виконано",
-    "Not completed" : "Не завершено",
+    "Mark as done" : "Позначити як виконане",
     "Unarchive card" : "Розархівувати картку",
     "Archive card" : "Архівувати картку",
     "Select Date" : "Вкажіть дату",
     "Assign a tag to this card…" : "Додати мітку до цієї картки",
     "(group)" : "(група)",
+    "Next week – {timeLocale}" : "Наступного тижня - {timeLocale}",
     "Todo items" : "Пункти завдань",
     "Edit card title" : "Редагувати заголовок картки",
-    "Card details" : "Деталі картки",
     "Assign to me" : "Призначити мені",
-    "Mark as done" : "Позначити як виконане",
-    "Move card" : "Пересунути картку",
     "Delete card" : "Вилучити картку",
-    "Move card to another board" : "Перемістити картку до іншої дошки",
-    "Select a list" : "Виберіть список",
     "seconds ago" : "секунд тому",
+    "Keyboard shortcuts" : "Скорочення",
+    "Keyboard shortcut" : "Сполучення клавіш",
+    "Action" : "Дія ",
+    "Shift" : "Shift",
+    "Ctrl" : "Ctrl",
+    "Search" : "Пошук",
+    "Enter" : "Ввід",
     "All boards" : "Усі дошки",
     "Archived boards" : "Архівні дошки",
     "Shared with you" : "Вам надано доступ",
     "Deck settings" : "Налаштування колоди",
     "Use bigger card view" : "Режим перегляду зі збільшеними картками",
     "Show boards in calendar/tasks" : "Показувати дошки в календарі та завданнях",
+    "Cancel edit" : "Скасувати редагування",
     "Board details" : "Деталі дошки",
     "Edit board" : "Редагувати дошку",
     "Clone board" : "Копіювати дошку",
@@ -193,7 +216,7 @@ OC.L10N.register(
     "Board {0} deleted" : "Дошку {0} вилучено",
     "No reminder" : "Відсутні нагадування",
     "An error occurred" : "Виникла помилка",
-    "Are you sure you want to delete the board {title}? This will delete all the data of this board including archived cards." : "Ви впевнені, що хочете вилучити дошку {title}? Це призведе до видалення всіх даних цієї дошки, включаючи архівні картки.",
+    "Are you sure you want to delete the board {title}? This will delete all the data of this board including archived cards." : "Ви впевнені, що хочете вилучити дошку {title}? Це призведе до видалення всіх даних цієї дошки, включно архівні картки.",
     "Delete the board?" : "Вилучити дошку?",
     "Today" : "Сьогодні",
     "Tomorrow" : "Завтра",
@@ -204,6 +227,7 @@ OC.L10N.register(
     "No upcoming cards" : "Немає майбутніх завдань",
     "upcoming cards" : "очікують на виконання",
     "Due on {date}" : "До {date}",
+    "This weekend – {timeLocale}" : "На цих вихідних - {timeLocale}",
     "Link to a board" : "Прив'язати до дошки",
     "Link to a card" : "Прив'язати до картки",
     "Message from {author} in {conversationName}" : "Повідомлення від {author} у {conversationName}",
@@ -211,13 +235,7 @@ OC.L10N.register(
     "Maximum file size of {size} exceeded" : "Досягнуто максимальний розмір файлу {size}",
     "Error creating the share" : "Помилка створення спільного доступу",
     "Share" : "Спільний доступ",
-    "Timeline" : "Дії",
-    "Add a new list" : "Додати новий список",
-    "Assign to users" : "Призначити користувачам",
-    "Due date" : "Протягом",
-    "Next week" : "Наступний тиждень",
-    "Next month" : "Наступний місяць",
-    "Limit deck usage of groups" : "Обмежити доступ до колоди для груп",
-    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Створення власних робочих дощок користувачам, які не входять у задані групи, буде заблоковано. Проте, такі користувачі зможуть продовжити працювати зі спільними дошками, до яких у них є доступ."
+    "(Circle)" : "(Коло)",
+    "Assign to users/groups/circles" : "Призначити користувачам/групам/колам"
 },
 "nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
