@@ -5,6 +5,7 @@ OC.L10N.register(
     "copy" : "copy",
     "Done" : "Done",
     "Cancel" : "Cancel",
+    "Open" : "Open",
     "Details" : "Details",
     "Sharing" : "Ulashish",
     "Tags" : "Tags",
@@ -17,6 +18,7 @@ OC.L10N.register(
     "Save" : "Save",
     "Update" : "Update",
     "seconds ago" : "seconds ago",
+    "Search" : "Search",
     "Shared with you" : "Shared with you",
     "Today" : "Today",
     "Close" : "Close"
