@@ -37,6 +37,10 @@ OC.L10N.register(
     "{user} has archived card {card} in list {stack} on board {board}" : "{user} 已將面板 {board} 上清單 {stack} 裏的卡片 {card} 封存",
     "You have unarchived card {card} in list {stack} on board {board}" : "您已將面板 {board} 上清單 {stack} 裏的卡片 {card} 解除封存",
     "{user} has unarchived card {card} in list {stack} on board {board}" : "{user} 已將面板 {board} 上清單 {stack} 裏的卡片 {card} 解除封存",
+    "You have marked the card {card} as done in list {stack} on board {board}" : "您已在佈告欄 {board} 上的列表 {stack} 標記卡片 {card} 為已完成",
+    "{user} has marked card {card} as done in list {stack} on board {board}" : "{user} 已在佈告欄 {board} 上的列表 {stack} 標記卡片 {card} 為已完成",
+    "You have marked the card {card} as undone in list {stack} on board {board}" : "您已在佈告欄 {board} 上的列表 {stack} 標記卡片 {card} 為未完成",
+    "{user} has marked the card {card} as undone in list {stack} on board {board}" : "{user} 已在佈告欄 {board} 上的列表 {stack} 標記卡片 {card} 為未完成",
     "You have removed the due date of card {card}" : "您移除了到期的卡片 {card}",
     "{user} has removed the due date of card {card}" : "{user} 移除了到期的卡片 {card}",
     "You have set the due date of card {card} to {after}" : "您已將卡片 {card} 的到期日設置為 {after}",
@@ -75,7 +79,7 @@ OC.L10N.register(
     "Personal" : "個人",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "%s 已將 “%s” 中的卡片 “%s” 指派給您。",
     "{user} has assigned the card {deck-card} on {deck-board} to you." : "{user} 已將 {deck-board} 中的卡片 {deck-card} 指派給您。",
-    "The card \"%s\" on \"%s\" has reached its due date." : "\"%s\"中的卡片 \"%s\" 已到期。",
+    "The card \"%s\" on \"%s\" has reached its due date." : "\"%s\" 中的卡片 \"%s\" 已到期。",
     "The card {deck-card} on {deck-board} has reached its due date." : "deck-board} 中的卡片{deck-card} 已到期。",
     "%s has mentioned you in a comment on \"%s\"." : "%s 在 “%s” 的意見中提到了您。",
     "{user} has mentioned you in a comment on {deck-card}." : "{user} 在 {deckcard} 的意見中提到了您。",
@@ -107,7 +111,7 @@ OC.L10N.register(
     "The file was only partially uploaded" : "檔案僅部分上傳",
     "No file was uploaded" : "沒有檔案被上傳",
     "Missing a temporary folder" : "找不到暫存資料夾",
-    "Could not write file to disk" : "寫入硬碟失敗",
+    "Could not write file to disk" : "無法將檔案寫入磁碟",
     "A PHP extension stopped the file upload" : "某個 PHP 擴充功能終止檔案的上傳",
     "No file uploaded or file size exceeds maximum of %s" : "沒有上傳檔案或檔案大小超過 %s 的最大值",
     "This comment has more than %s characters.\nAdded as an attachment to the card with name %s.\nAccessible on URL: %s." : "此評論超過%s個字符。\n作為附件添加到名稱為 %s 的卡片上。\n可於此 URL  存取：%s。",
@@ -116,13 +120,18 @@ OC.L10N.register(
     "Invalid date, date format must be YYYY-MM-DD" : "無效的日期，需為 YYYY-MM-DD 格式",
     "Personal planning and team project organization" : "個人規劃和團隊項目組織",
     "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in Markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your Markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Deck是一種看板式組織工具，旨在針對與Nextcloud集成的團隊進行個人計劃和項目組織。\n\n\n- 📥 添加您的任務到 card 及將之整理好\n- 📄 用 Markdown 寫下額外的註釋分享分享分享\n- 🔖 分配標籤以更好地組織您的工作\n- 👥 與您的團隊、朋友或家人分享\n- 📎 附加檔案並將其嵌入到您的 Markdown 描述中 \n- 💬 使用意見與您的團隊討論\n- ⚡ 在活動流中跟踪更改\n- 🚀 讓您的專案井井有條",
+    "Card details" : "卡片詳情",
     "Add board" : "添加面板",
     "Select the board to link to a project" : "選擇要連結到一個項目的面板",
     "Search by board title" : "通過標題搜索面板",
     "Select board" : "選擇面板",
+    "Move card to another board" : "將卡片移到其他面板",
     "Select a board" : "選擇一個面板",
-    "Select a card" : "選擇卡片",
+    "No lists available" : "無清單可用",
+    "Select a list" : "選擇一個列表",
+    "Move card" : "移動卡片",
     "Cancel" : "取消",
+    "Select a card" : "選擇卡片",
     "Select the card to link to a project" : "選擇要連結到一個項目的卡片",
     "Link to card" : "連結到卡片",
     "File already exists" : "檔案已存在",
@@ -141,6 +150,10 @@ OC.L10N.register(
     "Filter by tag" : "以標籤過濾",
     "Filter by assigned user" : "以指派用戶過濾",
     "Unassigned" : "未指派",
+    "Filter by status" : "以狀態過濾",
+    "Open and completed" : "開啟並完成",
+    "Open" : "開啟",
+    "Completed" : "已完成",
     "Filter by due date" : "以到期日過濾",
     "Overdue" : "逾期",
     "Next 24 hours" : "未來24小時",
@@ -159,9 +172,8 @@ OC.L10N.register(
     "Details" : "詳情",
     "Currently present people" : "目前在場人仕",
     "Loading board" : "正在加載面板",
-    "No lists available" : "無清單可用",
-    "Create a new list to add cards to this board" : "創建一張新清單來添加卡片到這個看板",
     "Board not found" : "未找到面板",
+    "Create a new list to add cards to this board" : "創建一張新清單來添加卡片到這個看板",
     "Sharing" : "正在分享",
     "Tags" : "標籤",
     "Deleted items" : "已刪除項目",
@@ -169,12 +181,12 @@ OC.L10N.register(
     "Deleted lists" : "已刪除的清單",
     "Undo" : "撤消",
     "Deleted cards" : "已刪除卡片",
-    "Share board with a user, group or circle …" : "與一個用戶、群組或圈子分享面板...",
-    "Searching for users, groups and circles …" : "正在搜尋用戶、群組和圈子 ......",
+    "Share board with a user, group or team …" : "與用戶、群組或團隊分享面板 …",
+    "Searching for users, groups and teams …" : "搜尋使用者、群組與團隊 …",
     "No participants found" : "未找到參與者",
     "Board owner" : "面板板主",
     "(Group)" : "（群組）",
-    "(Circle)" : "（圈子）",
+    "(Team)" : "（團隊）",
     "Can edit" : "可以編輯",
     "Can share" : "可以分享",
     "Can manage" : "可以管理",
@@ -200,8 +212,9 @@ OC.L10N.register(
     "title and color value must be provided" : "必須提供標題和顏色值",
     "Board name" : "面板名",
     "Members" : "成員",
-    "Assign to users/groups/circles" : "指派給用戶/群組/圈子",
+    "Assign to users/groups/team" : "分配給用戶／群組／團隊",
     "Assign a user to this card…" : "將此卡片指派給用戶...",
+    "Select a user to assign to this card…" : "選擇一個用戶賦值給此卡片...",
     "Upload new files" : "上傳新檔案",
     "Share from Files" : "從檔案進行分享",
     "Pending share" : "等待分享",
@@ -244,8 +257,9 @@ OC.L10N.register(
     "Add due date" : "添加到期日",
     "Choose a date" : "選擇日期",
     "Remove due date" : "移除到期日",
-    "Completed" : "已完成",
-    "Not completed" : "未完成",
+    "Mark as done" : "標記為完成",
+    "Due at:" : "到期日：",
+    "Not done" : "未完成",
     "Unarchive card" : "取消對卡片的封存",
     "Archive card" : "封存卡片",
     "Select Date" : "選擇日期",
@@ -254,22 +268,45 @@ OC.L10N.register(
     "Set due date for this weekend" : "設定本週末的到期日",
     "Set due date for next week" : "設定下星期的到期日",
     "Assign a tag to this card…" : "為該卡片分配標籤…",
+    "Select or create a tag…" : "選擇或創建標籤 ...",
+    "Create a new tag:" : "創建新標籤：",
     "(group)" : "（群組）",
     "Next week – {timeLocale}" : "下星期 – {timeLocale}",
     "Todo items" : "待辦事項",
     "{count} comments, {unread} unread" : "{count} 條評論，{unread} 條未讀",
     "Edit card title" : "編輯卡片標題",
-    "Card details" : "卡片詳情",
     "Assign to me" : "指派給我",
     "Unassign myself" : "自己解除指派",
-    "Mark as done" : "標記為完成",
-    "Move card" : "移動卡片",
+    "Mark as not done" : "標記為未完成",
     "Delete card" : "刪除卡片",
-    "Move card to another board" : "將卡片移到其他面板",
-    "Select a list" : "選擇一個列表",
-    "List is empty" : "列表是空的",
     "Card deleted" : "卡片被刪除",
     "seconds ago" : "幾秒前",
+    "Keyboard shortcuts" : "鍵盤快捷鍵",
+    "Boost your productivity using Deck with keyboard shortcuts." : "提高您的生產力，在 Deck 上使用鍵盤快捷鍵。",
+    "Board actions" : "面板操作",
+    "Keyboard shortcut" : "鍵盤快捷鍵",
+    "Action" : "操作",
+    "Shift" : "轉移",
+    "Scroll" : "滾動",
+    "Scroll sideways" : "橫向滾動",
+    "Navigate between cards" : "在卡片間移動",
+    "Esc" : "Esc",
+    "Close card details" : "關閉卡片詳細資訊",
+    "Ctrl" : "Ctrl",
+    "Search" : "搜尋",
+    "Show card filters" : "顯示卡片篩選條件",
+    "Clear card filters" : "清除卡片篩選條件",
+    "Show help dialog" : "顯示幫助對話框",
+    "Card actions" : "卡片操作",
+    "The following actions can be triggered on the currently highlighted card" : "可以在目前突顯的卡片上觸發以下操作",
+    "Enter" : "輸入",
+    "Space" : "空間",
+    "Open card details" : "打開卡片細節",
+    "Edit the card title" : "編輯卡片標題",
+    "Assign yourself to the current card" : "將自己指派給目前卡片",
+    "Archive/unarchive the current card" : "封存/解除封存目前卡片",
+    "Mark card as completed/not completed" : "將卡片標記為完成/未完成",
+    "Open card menu" : "打開卡片選項單",
     "All boards" : "全部面板",
     "Archived boards" : "已封存面板",
     "Shared with you" : "收到的分享",
@@ -279,6 +316,8 @@ OC.L10N.register(
     "Show boards in calendar/tasks" : "在日曆/任務中顯示面板",
     "Limit board creation to some groups" : "限制面板只能由某些群組創建",
     "Users outside of those groups will not be able to create their own boards, but will still be able to work on boards that have been shared with them." : "這些群組之外的用戶將無法創建自己的面板，但仍然可以在與他們共享的面板上工作。",
+    "Cancel edit" : "取消編輯",
+    "Save board" : "保存面板",
     "Board details" : "面板詳情",
     "Edit board" : "編輯面板",
     "Clone board" : "複製面板",
@@ -303,8 +342,7 @@ OC.L10N.register(
     "Tomorrow" : "明日",
     "No due" : "沒有到期的",
     "Search for {searchQuery} in all boards" : "在所有面板中搜索 {searchQuery}",
-    "No results found" : "沒有結果",
-    "This weekend – {timeLocale}" : "本週末 – {timeLocale}",
+    "No results found" : "未找到結果",
     "Deck board {name}\n* Last modified on {lastMod}" : "Deck 面板 {name}\n* 最後修改於  {lastMod}",
     "{stack} in {board}" : "{board} 中的 {stack}",
     "Click to expand description" : "點擊展開描述",
@@ -324,6 +362,7 @@ OC.L10N.register(
     "upcoming cards" : "快將到期的卡片",
     "New card" : "新卡片",
     "Due on {date}" : "於 {date} 到期",
+    "This weekend – {timeLocale}" : "本週末 – {timeLocale}",
     "Tomorrow – {timeLocale}" : "明天 – {timeLocale}",
     "Later today – {timeLocale}" : "今天稍後 – {timeLocale}",
     "Link to a board" : "連結到面板",
@@ -337,14 +376,9 @@ OC.L10N.register(
     "Share with a Deck card" : "用一張 Deck 卡片進行分享 ",
     "Share {file} with a Deck card" : "用一張 Deck 卡片分享 {file}",
     "Share" : "分享",
-    "A <strong>card description</strong> inside the Deck app has been changed" : "Deck 應用程式中的 <strong>卡片描述</strong> 已改變",
-    "Timeline" : "時間線",
-    "Add a new list" : "添加一張新清單",
-    "Assign to users" : "指派給用戶",
-    "Due date" : "到期日",
-    "Next week" : "下星期",
-    "Next month" : "下個月",
-    "Limit deck usage of groups" : "限制群組使用 Deck",
-    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "限制 Deck 將阻止不屬於這些群組的用戶創建自己的面板。用戶仍然可以在與他們的面板上工作。"
+    "Searching for users, groups and circles …" : "正在搜尋用戶、群組和圈子 ......",
+    "(Circle)" : "（圈子）",
+    "Assign to users/groups/circles" : "指派給用戶/群組/圈子",
+    "Filter by completed" : "按已完成篩選"
 },
 "nplurals=1; plural=0;");
