@@ -1,71 +1,39 @@
 <?php
 /**
- * @copyright Copyright (c) 2016 Julius Härtl <jus@bitgrid.net>
- *
- * @author Julius Härtl <jus@bitgrid.net>
- *
- * @license GNU AGPL version 3 or any later version
- *
- *  This program is free software: you can redistribute it and/or modify
- *  it under the terms of the GNU Affero General Public License as
- *  published by the Free Software Foundation, either version 3 of the
- *  License, or (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Affero General Public License for more details.
- *
- *  You should have received a copy of the GNU Affero General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2016 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Deck\Db;
 
-use OC\Cache\CappedMemoryCache;
 use OCA\Deck\Service\CirclesService;
 use OCP\AppFramework\Db\DoesNotExistException;
 use OCP\AppFramework\Db\QBMapper;
+use OCP\Cache\CappedMemoryCache;
 use OCP\DB\QueryBuilder\IQueryBuilder;
 use OCP\IDBConnection;
-use OCP\IUserManager;
 use OCP\IGroupManager;
+use OCP\IUserManager;
 use Psr\Log\LoggerInterface;
 
 /** @template-extends QBMapper<Board> */
 class BoardMapper extends QBMapper implements IPermissionMapper {
-	private $labelMapper;
-	private $aclMapper;
-	private $stackMapper;
-	private $userManager;
-	private $groupManager;
-	private $circlesService;
-	private $logger;
-
 	/** @var CappedMemoryCache<Board[]> */
-	private $userBoardCache;
+	private CappedMemoryCache $userBoardCache;
 	/** @var CappedMemoryCache<Board> */
-	private $boardCache;
+	private CappedMemoryCache $boardCache;
 
 	public function __construct(
 		IDBConnection $db,
-		LabelMapper $labelMapper,
-		AclMapper $aclMapper,
-		StackMapper $stackMapper,
-		IUserManager $userManager,
-		IGroupManager $groupManager,
-		CirclesService $circlesService,
-		LoggerInterface $logger
+		private LabelMapper $labelMapper,
+		private AclMapper $aclMapper,
+		private StackMapper $stackMapper,
+		private IUserManager $userManager,
+		private IGroupManager $groupManager,
+		private CirclesService $circlesService,
+		private LoggerInterface $logger
 	) {
 		parent::__construct($db, 'deck_boards', Board::class);
-		$this->labelMapper = $labelMapper;
-		$this->aclMapper = $aclMapper;
-		$this->stackMapper = $stackMapper;
-		$this->userManager = $userManager;
-		$this->groupManager = $groupManager;
-		$this->circlesService = $circlesService;
-		$this->logger = $logger;
 
 		$this->userBoardCache = new CappedMemoryCache();
 		$this->boardCache = new CappedMemoryCache();
@@ -80,29 +48,32 @@ class BoardMapper extends QBMapper implements IPermissionMapper {
 	 * @throws \OCP\AppFramework\Db\MultipleObjectsReturnedException
 	 * @throws DoesNotExistException
 	 */
-	public function find($id, $withLabels = false, $withAcl = false): Board {
-		if (!isset($this->boardCache[$id])) {
+	public function find(int $id, bool $withLabels = false, bool $withAcl = false, bool $allowDeleted = false): Board {
+		$cacheKey = (string)$id;
+		if (!isset($this->boardCache[$cacheKey])) {
 			$qb = $this->db->getQueryBuilder();
+			$deletedWhere = $allowDeleted ? $qb->expr()->gte('deleted_at', $qb->createNamedParameter(0, IQueryBuilder::PARAM_INT)) : $qb->expr()->eq('deleted_at', $qb->createNamedParameter(0, IQueryBuilder::PARAM_INT));
 			$qb->select('*')
 				->from('deck_boards')
 				->where($qb->expr()->eq('id', $qb->createNamedParameter($id, IQueryBuilder::PARAM_INT)))
+				->andWhere($deletedWhere)
 				->orderBy('id');
-			$this->boardCache[$id] = $this->findEntity($qb);
+			$this->boardCache[(string)$id] = $this->findEntity($qb);
 		}
 
 		// Add labels
-		if ($withLabels && $this->boardCache[$id]->getLabels() === null) {
+		if ($withLabels && $this->boardCache[$cacheKey]->getLabels() === null) {
 			$labels = $this->labelMapper->findAll($id);
-			$this->boardCache[$id]->setLabels($labels);
+			$this->boardCache[$cacheKey]->setLabels($labels);
 		}
 
 		// Add acl
-		if ($withAcl && $this->boardCache[$id]->getAcl() === null) {
+		if ($withAcl && $this->boardCache[$cacheKey]->getAcl() === null) {
 			$acl = $this->aclMapper->findAll($id);
-			$this->boardCache[$id]->setAcl($acl);
+			$this->boardCache[$cacheKey]->setAcl($acl);
 		}
 
-		return $this->boardCache[$id];
+		return $this->boardCache[$cacheKey];
 	}
 
 	public function findBoardIds(string $userId): array {
@@ -157,7 +128,7 @@ class BoardMapper extends QBMapper implements IPermissionMapper {
 	}
 
 	public function findAllForUser(string $userId, ?int $since = null, bool $includeArchived = true, ?int $before = null,
-								   ?string $term = null): array {
+		?string $term = null): array {
 		$useCache = ($since === -1 && $includeArchived === true && $before === null && $term === null);
 		if (!isset($this->userBoardCache[$userId]) || !$useCache) {
 			$groups = $this->groupManager->getUserGroupIds(
@@ -196,7 +167,7 @@ class BoardMapper extends QBMapper implements IPermissionMapper {
 	 * Find all boards for a given user
 	 */
 	public function findAllByUser(string $userId, ?int $limit = null, ?int $offset = null, ?int $since = null,
-								  bool $includeArchived = true, ?int $before = null, ?string $term = null): array {
+		bool $includeArchived = true, ?int $before = null, ?string $term = null): array {
 		// FIXME this used to be a UNION to get boards owned by $userId and the user shares in one single query
 		// Is it possible with the query builder?
 		$qb = $this->db->getQueryBuilder();
@@ -303,7 +274,7 @@ class BoardMapper extends QBMapper implements IPermissionMapper {
 	 * Find all boards for a given user
 	 */
 	public function findAllByGroups(string $userId, array $groups, ?int $limit = null, ?int $offset = null, ?int $since = null,
-									bool $includeArchived = true, ?int $before = null, ?string $term = null): array {
+		bool $includeArchived = true, ?int $before = null, ?string $term = null): array {
 		if (count($groups) <= 0) {
 			return [];
 		}
@@ -357,7 +328,7 @@ class BoardMapper extends QBMapper implements IPermissionMapper {
 	}
 
 	public function findAllByCircles(string $userId, ?int $limit = null, ?int $offset = null, ?int $since = null,
-									 bool $includeArchived = true, ?int $before = null, ?string $term = null) {
+		bool $includeArchived = true, ?int $before = null, ?string $term = null) {
 		$circles = $this->circlesService->getUserCircles($userId);
 		if (count($circles) === 0) {
 			return [];
@@ -412,6 +383,51 @@ class BoardMapper extends QBMapper implements IPermissionMapper {
 		return $entries;
 	}
 
+	public function findAllByTeam(string $teamId): array {
+		$qb = $this->db->getQueryBuilder();
+		$qb->select('b.id', 'title', 'owner', 'color', 'archived', 'deleted_at', 'last_modified')
+			->from('deck_boards', 'b')
+			->innerJoin('b', 'deck_board_acl', 'acl', $qb->expr()->eq('b.id', 'acl.board_id'))
+			->where($qb->expr()->eq('acl.type', $qb->createNamedParameter(Acl::PERMISSION_TYPE_CIRCLE, IQueryBuilder::PARAM_INT)))
+			->andWhere($qb->expr()->eq('acl.participant', $qb->createNamedParameter($teamId, IQueryBuilder::PARAM_STR)));
+		$entries = $this->findEntities($qb);
+		foreach ($entries as $entry) {
+			$entry->setShared(2);
+		}
+		return $entries;
+	}
+
+	public function findTeamsForBoard(int $boardId): array {
+		$qb = $this->db->getQueryBuilder();
+		$qb->select('acl.participant')
+			->from('deck_boards', 'b')
+			->innerJoin('b', 'deck_board_acl', 'acl', $qb->expr()->eq('b.id', 'acl.board_id'))
+			->where($qb->expr()->eq('b.id', $qb->createNamedParameter($boardId, IQueryBuilder::PARAM_INT)))
+			->andWhere($qb->expr()->eq('acl.type', $qb->createNamedParameter(Acl::PERMISSION_TYPE_CIRCLE, IQueryBuilder::PARAM_INT)));
+
+		$result = $qb->executeQuery();
+		return array_map(function ($entry) {
+			return $entry['participant'];
+		}, $result->fetchAll());
+	}
+
+	public function isSharedWithTeam(int $boardId, string $teamId): bool {
+		$qb = $this->db->getQueryBuilder();
+		$qb->select('b.id', 'title', 'owner', 'color', 'archived', 'deleted_at', 'last_modified')
+			->from('deck_boards', 'b')
+			->innerJoin('b', 'deck_board_acl', 'acl', $qb->expr()->eq('b.id', 'acl.board_id'))
+			->where($qb->expr()->eq('b.id', $qb->createNamedParameter($boardId, IQueryBuilder::PARAM_INT)))
+			->andWhere($qb->expr()->eq('acl.type', $qb->createNamedParameter(Acl::PERMISSION_TYPE_CIRCLE, IQueryBuilder::PARAM_INT)))
+			->andWhere($qb->expr()->eq('acl.participant', $qb->createNamedParameter($teamId, IQueryBuilder::PARAM_STR)));
+		try {
+			$this->findEntity($qb);
+			return true;
+		} catch (DoesNotExistException $e) {
+			// Expected return falue
+		}
+		return false;
+	}
+
 	public function findAll(): array {
 		$qb = $this->db->getQueryBuilder();
 		$qb->select('id')
@@ -462,8 +478,7 @@ class BoardMapper extends QBMapper implements IPermissionMapper {
 	}
 
 	public function mapAcl(Acl &$acl) {
-		$groupManager = $this->groupManager;
-		$acl->resolveRelation('participant', function ($participant) use (&$acl, &$userManager, &$groupManager) {
+		$acl->resolveRelation('participant', function ($participant) use (&$acl) {
 			if ($acl->getType() === Acl::PERMISSION_TYPE_USER) {
 				if ($this->userManager->userExists($acl->getParticipant())) {
 					return new User($acl->getParticipant(), $this->userManager);
@@ -472,7 +487,7 @@ class BoardMapper extends QBMapper implements IPermissionMapper {
 				return null;
 			}
 			if ($acl->getType() === Acl::PERMISSION_TYPE_GROUP) {
-				$group = $groupManager->get($participant);
+				$group = $this->groupManager->get($participant);
 				if ($group !== null) {
 					return new Group($group);
 				}
